#include <iostream>
#include <vector>
#include <algorithm>
#include <numeric>
#include <unordered_map>
#include <unordered_set>
#include <random>
using namespace std;

int VOTES = 20;

bool dfs(int u, vector<vector<int>> &adj, vector<int> &visited) {
    if (visited[u] != 0) {
        return visited[u] == 1;
    }

    visited[u] = 1;

    for (auto v: adj[u]) {
        if (dfs(v, adj, visited)) {
            return true;
        }
    }

    visited[u] = 2;

    return false;
}

bool loop_detect(vector<vector<int>> &adj) {
    vector<int> visited(adj.size(), 0);

    for (unsigned int u=0; u<adj.size(); u++) {
        if (visited[u] == 0) {
            if (dfs(u, adj, visited)) {
                return true;
            }
        }
    }

    return false;
}

int main() {
    int N, D;
    cin >> N;

    unordered_map<string, int> words;
    vector<string> words_back(N);
    vector<vector<int>> G(N), G_rev(N);
    vector<bool> is_sink(N, true);

    cin >> D;
    for (int i=0; i<D; i++) {
        string x;
        cin >> x;
        if (!words.count(x)) {
            words[x] = words.size();
            words_back[words[x]] = x;
        }
        int u = words[x];
        is_sink[u] = false;

        int k;
        cin >> k;

        while (k--) {
            string y;
            cin >> y;
            if (!words.count(y)) {
                words[y] = words.size();
                words_back[words[y]] = y;
            }
            int v = words[y];

            // cout << u << " -> " << v << endl;
            G[u].push_back(v);
            G_rev[v].push_back(u);
        }
    }

    // for (int u=0; u<N; u++) {
    //     cout << u << ": ";
    //     for (int v: G[u]) {
    //         cout << v << " ";
    //     }
    //     cout << endl;
    // }
    

    // best solution among all papers
    vector<int> overall_solution;
    
    mt19937 generator;
    

    // paper 1: random strategy
    for (int REP = 0; REP < 500000/(N+D); ++REP) {
        vector<int> to_process, primitive;
        for (int i=0; i<N; i++) {
            if (is_sink[i]) {
                primitive.push_back(i);
            } else {
                to_process.push_back(i);
            }
        }

        // Random strategy
        shuffle(to_process.begin(), to_process.end(), generator);

        unordered_set<int> in_G_prime;
        vector<vector<int>> G_prime(N);
        for (int node: to_process) {
            // add the node to G'
            in_G_prime.insert(node);

            // add all outgoing arcs
            for (int u: G[node]) {
                if (in_G_prime.count(u)) {
                    G_prime[node].push_back(u);
                }
            }

            // add all incoming arcs
            for (int u: G_rev[node]) {
                if (in_G_prime.count(u)) {
                    G_prime[u].push_back(node);
                }
            }

            // if a loop was formed
            if (loop_detect(G_prime)) {
                // undo incoming arcs
                for (int u: G_rev[node]) {
                    if (in_G_prime.count(u)) {
                        G_prime[u].pop_back();
                    }
                }

                // undo outgoing arcs
                for (int u: G[node]) {
                    if (in_G_prime.count(u)) {
                        G_prime[node].pop_back();
                    }
                }

                // undo adding node to G'
                in_G_prime.erase(node);

                // put the node in P
                primitive.push_back(node);
            }
        }
        if (primitive.size() > overall_solution.size())
            overall_solution = std::move(primitive);
    }
    
    
    // paper 2: frequencies strategy
    {
        vector<int> to_process, primitive;
        for (int i=0; i<N; i++) {
            if (is_sink[i]) {
                primitive.push_back(i);
            } else {
                to_process.push_back(i);
            }
        }

        // Frequencies strategy
        sort(to_process.begin(), to_process.end(), [G_rev](const int &u, const int &v) {
            return G_rev[v].size() > G_rev[u].size();
        });

        unordered_set<int> in_G_prime;
        vector<vector<int>> G_prime(N);
        for (int node: to_process) {
            // add the node to G'
            in_G_prime.insert(node);

            // add all outgoing arcs
            for (int u: G[node]) {
                if (in_G_prime.count(u)) {
                    G_prime[node].push_back(u);
                }
            }

            // add all incoming arcs
            for (int u: G_rev[node]) {
                if (in_G_prime.count(u)) {
                    G_prime[u].push_back(node);
                }
            }

            // if a loop was formed
            if (loop_detect(G_prime)) {
                // undo incoming arcs
                for (int u: G_rev[node]) {
                    if (in_G_prime.count(u)) {
                        G_prime[u].pop_back();
                    }
                }

                // undo outgoing arcs
                for (int u: G[node]) {
                    if (in_G_prime.count(u)) {
                        G_prime[node].pop_back();
                    }
                }

                // undo adding node to G'
                in_G_prime.erase(node);

                // put the node in P
                primitive.push_back(node);
            }
        }
        if (primitive.size() < overall_solution.size())
            overall_solution = std::move(primitive);
    }
    
    
    // paper 4: voting strategy
    vector<int> possible_votes = {3, 5, 7, 10, 13, 16, 20, 25, 30, 35, 40, 50, 60, 80, 100};
    for (int __v__ : possible_votes) {
        VOTES = __v__;
        vector<int> to_process, sinks;
        for (int i=0; i<N; i++) {
            if (is_sink[i]) {
                sinks.push_back(i);
            } else {
                to_process.push_back(i);
            }
        }

        // Random voting strategy
        vector<int> primitive[VOTES + 1];
        vector<int> set_count(N);

        auto check = [=, &set_count, &primitive](int vote_i) {
            unordered_set<int> in_G_prime;
            vector<vector<int>> G_prime(N);
            for (int node: to_process) {
                // add the node to G'
                in_G_prime.insert(node);

                // add all outgoing arcs
                for (int u: G[node]) {
                    if (in_G_prime.count(u)) {
                        G_prime[node].push_back(u);
                    }
                }

                // add all incoming arcs
                for (int u: G_rev[node]) {
                    if (in_G_prime.count(u)) {
                        G_prime[u].push_back(node);
                    }
                }

                // if a loop was formed
                if (loop_detect(G_prime)) {
                    // undo incoming arcs
                    for (int u: G_rev[node]) {
                        if (in_G_prime.count(u)) {
                            G_prime[u].pop_back();
                        }
                    }

                    // undo outgoing arcs
                    for (int u: G[node]) {
                        if (in_G_prime.count(u)) {
                            G_prime[node].pop_back();
                        }
                    }

                    // undo adding node to G'
                    in_G_prime.erase(node);

                    // put the node in P
                    primitive[vote_i].push_back(node);

                    // take note that this node appears in one of the P sets
                    set_count[node] += 1;
                }
            }
        };

        for (int vote_i=0; vote_i<VOTES; vote_i++) {
            shuffle(to_process.begin(), to_process.end(), generator);
            check(vote_i);
        }

        sort(to_process.begin(), to_process.end(), [set_count, G_rev](const int &a, const int &b){
            if (set_count[a] == 0 && set_count[b] == 0) {
                // both nodes don't appear in any set, so order by frequency
                return G_rev[a].size() < G_rev[b].size();
            }

            if (set_count[a] == set_count[b]) {
                // both nodes appear in the same number of sets, so order by inverse of frequency
                return G_rev[a].size() > G_rev[b].size();
            }

            if (set_count[a] == 0) return true;
            if (set_count[b] == 0) return false;

            // none of them is zero, order by inverse of set count
            return set_count[a] > set_count[b];
        });

        // last pass using the smarter heuristic order
        check(VOTES);
        if (sinks.size() + primitive[VOTES].size() < overall_solution.size()) {
            overall_solution = std::move(sinks);
            overall_solution.insert(overall_solution.end(), primitive[VOTES].begin(), primitive[VOTES].end());
        }
    }

    cout << overall_solution.size() << endl;
    for (int p : overall_solution) {
        cout << words_back[p] << endl;
    }
}
