/*
 * Optimal solution for sum.
 * Starting from the less significant digits, the solution tries all the
 * possible combinations of values to be assigne to the letters, making
 * sure to stop the computation as soon as possible if an error is found.
 *
 * Author: Marco Donadoni
 *
 * Complexity: At most half of the letters are bruteforced, the other half
 * is always fixed by some previous knowledge.
 */

#include <stdio.h>
#include <assert.h>
#include <string.h>
#include <algorithm>
#include <cassert>
#include <iostream>

using namespace std;

// constraints
#define MAXN 10000
#define DIGITS 10 

// input data
int N, M;
char op1[2*MAXN], op2[2*MAXN], res[2*MAXN];

bool taken[10];
int assigned[10];
bool found;

void find_op(int p, int r) {
    if (p >= N) {
        // If the last remainder is correct set found to true
        if ((M > N && r == 1) || (M == N && r == 0)) {
            found = true;
        }
        // if one of the operands starts with zero, set found to false
        if (N > 1 && (assigned[op1[N-1]] == 0 || assigned[op2[N-1]] == 0)) {
            found = false;
        }
        return;
    }

    if (assigned[op1[p]] == -1 && assigned[op2[p]] == -1) {
        if (op1[p] != op2[p]) {
            // Both letters are different and not assigned
            // Bruteforce one of the two and get the other
            for (int d = 0; d < DIGITS && !found; d++) {
                int a = d, b = (res[p] - r - d + 10) % 10;
                if ((a == b) || taken[a] || taken[b]) {
                    continue;
                }

                taken[a] = taken[b] = true;
                assigned[op1[p]] = a;
                assigned[op2[p]] = b;
                find_op(p+1, (a + b + r) / 10);

                if (!found) {
                    taken[a] = taken[b] = false;
                    assigned[op1[p]] = assigned[op2[p]] = -1;
                }
            }
        } else {
            if ((res[p] - r + 10) % 2 == 1) {
                return;
            }

            // Same letters, only two values are good
            for (int k = 0; k < 2 && !found; k++) {
                int d = ((res[p] - r + 10)/2 + k*5)%10;
                if (!taken[d]) {
                    taken[d] = true;
                    assigned[op1[p]] = d;
                    find_op(p+1, (d+d+r)/10);

                    if (!found) {
                        taken[d] = false;
                        assigned[op1[p]] = -1;
                    }
                }
            }
        }
    } else {
        // At most one is not assigned, let's make it op1
        bool swapped = false;
        if (assigned[op2[p]] == -1) {
            swap(op1[p], op2[p]);
            swapped = true;
        }

        if (assigned[op1[p]] == -1) {
            // First not assigned, get digit from op2
            int d = (res[p] - r - assigned[op2[p]] + 10) % 10;
            if (!taken[d]) {
                assigned[op1[p]] = d;
                taken[d] = true;
                find_op(p+1, (assigned[op2[p]] + d + r)/10);

                if (!found) {
                    assigned[op1[p]] = -1;
                    taken[d] = false;
                }
            }
        } else {
            // Both letters are fixed, check that the sum is right
            if ((assigned[op1[p]] + assigned[op2[p]] + r) % 10 == res[p]) {
                find_op(p+1, (assigned[op1[p]] + assigned[op2[p]] + r)/10);
            }
        }

        if (swapped) {
            swap(op1[p], op2[p]);
        }
    }
}




int main() {
//  uncomment the following lines if you want to read/write from files
//  freopen("input.txt", "r", stdin);
//  freopen("output.txt", "w", stdout);

    scanf("%s", &op1[0]);
    scanf("%s", &op2[0]);
    scanf("%s", &res[0]);
    N = strlen(op1);
    M = strlen(res);
    assert(strlen(op1) == strlen(op2));
    
    // insert your code here
    // NOTE: both operands and result are read as strings
    
    for (int i = 0; i < N; i++) {
        op1[i] -= 'A';
        op2[i] -= 'A';
    }

    for (int i = 0; i < M; i++) {
        res[i] -= '0';
    }

    for (int i = 0; i < DIGITS; i++) {
        assigned[i] = -1;
    }

    reverse(op1, op1+N);
    reverse(op2, op2+N);
    reverse(res, res+M);

    find_op(0, 0);

    assert(found);
    for (int i = N-1; i >= 0; i--) {
        printf("%d", assigned[op1[i]]);
    }
    printf("\n");
    for (int i = N-1; i >= 0; i--) {
        printf("%d", assigned[op2[i]]);
    }
    printf("\n");

    return 0;
}
